'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.default = loader;

var _loaderUtils = require('loader-utils');

var _loaderUtils2 = _interopRequireDefault(_loaderUtils);

var _configs = require('infuse.host/lib/configs.js');

var _configs2 = _interopRequireDefault(_configs);

var _createESModule = require('infuse.host/lib/createESModule.js');

var _createESModule2 = _interopRequireDefault(_createESModule);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Parses all template elements in the given HTML document and generates an ES module.
 *
 * @param {(string|Document)} htmlDocument The HTML document, as a string or as an instance of
 *     `Document`, to parse and convert into an ES module.
 * @returns {string} The source code of the generated ES module.
 */
function loader(htmlDocument) {
	// Get options for this loader given.
	const options = _loaderUtils2.default.getOptions(this) || {};
	// Find all the keys in `options` that are configuration options.
	const configKeys = Object.keys(options).filter(key => _configs2.default.has(key));

	// Set configurations, if `options` includes configuration options.
	if (configKeys.length > 0) {
		// An array of key/value configuration pairs (an array or arrays).
		const configOptions = configKeys.map(key => [key, options[key]]);
		(0, _configs.setConfigs)(configOptions);
	}

	return (0, _createESModule2.default)(htmlDocument, options);
}